==> promiseland-0.0.14.tgz: package/test/test/leaveTry.js <==
(function(){
  var defineFun;
  var requireFun;
  
  if (typeof exports == "object" && typeof module == "object"){ // CommonJS
    requireFun = function(modulesAr, callback, errBack){
      try{
        var i = 0;
        var l = modulesAr.length;
        var args = [];
        for (i; i < l; ++i){
          args.push(require(modulesAr[i]));
        };
      }catch(e){
        errBack(e);
        return;
      };
      callback.apply(callback, args);
    };
    defineFun = function(requireAr, callback){
      requireFun(requireAr, function(){
        module.exports = callback.apply(callback, arguments);
      });
    };
    
  }else if (typeof define == "function" && define.amd){ // AMD
    var _define = define;
    requireFun = require;
    
    defineFun = function(par1, par2){
      if (par1 instanceof Array){
        par1.unshift("require");
      }else{
        par2 = par1;
        par1 = ["require"];
      };
      _define(par1, function(){
        requireFun = arguments[0];
        var args = [];
        for (var i = 1; i < arguments.length; ++i){
          args.push(arguments[i]);
        };
        return par2.apply(par2, args);
      });
    };
    
  }else{ // Plain browser env
    alert("not working out!");
    
  };
  defineFun(["promiseland"], function(promiseland){
var __require = requireFun;

if (promiseland._hasModule({ hashStr: "3d47d09748a57e8018c6827e5bc8604d" })){ return promiseland._getModule("3d47d09748a57e8018c6827e5bc8604d"); };
var PL$4/*some*/;try{PL$4/*some*/ = some;}catch(e){};
var PL$1 = (function(){
"use strict";
var PL$2/*catched*/;
var PL$3/*res*/;
;
try
{PL$2/*catched*/;
PL$3/*res*/ = PL$4/*some*/["error"]();
}catch(PL$5/*e*/){PL$2/*catched*/ = true;;
};
;
if(! PL$2/*catched*/){
return {"success": false};;
};
;
return {"success": true};;
;
})();
;return PL$1;
});
})();

==> promiseland-0.0.17.tgz: package/test/test/leaveTry.js <==
(function(){
  var defineFun;
  var requireFun;
  
  if (typeof exports == "object" && typeof module == "object"){ // CommonJS
    requireFun = function(modulesAr, callback, errBack){
      try{
        var i = 0;
        var l = modulesAr.length;
        var args = [];
        for (i; i < l; ++i){
          args.push(require(modulesAr[i]));
        };
      }catch(e){
        errBack(e);
        return;
      };
      callback.apply(callback, args);
    };
    defineFun = function(requireAr, callback){
      requireFun(requireAr, function(){
        module.exports = callback.apply(callback, arguments);
      });
    };
    
  }else if (typeof define == "function" && define.amd){ // AMD
    var _define = define;
    requireFun = require;
    
    defineFun = function(par1, par2){
      if (par1 instanceof Array){
        par1.unshift("require");
      }else{
        par2 = par1;
        par1 = ["require"];
      };
      _define(par1, function(){
        requireFun = arguments[0];
        var args = [];
        for (var i = 1; i < arguments.length; ++i){
          args.push(arguments[i]);
        };
        return par2.apply(par2, args);
      });
    };
    
  }else{ // Plain browser env
    alert("not working out!");
    
  };
  defineFun(["promiseland"], function(promiseland){
var __require = requireFun;

if (promiseland._hasModule({ hashStr: "3d47d09748a57e8018c6827e5bc8604d" })){ return promiseland._getModule("3d47d09748a57e8018c6827e5bc8604d"); };
var PL$4/*some*/;try{PL$4/*some*/ = some;}catch(e){};
var PL$1 = (function(){
"use strict";

  ;
  try
  {
    var PL$2/*catched*/;
    ;
    var PL$3/*res*/ = PL$4/*some*/["error"]();
    ;}catch(PL$5/*e*/){
    PL$2/*catched*/ = true;};
  ;
  if(! PL$2/*catched*/){
    return {
      "success": false
    };
  };
  ;
  return {
    "success": true
  };
  ;})();
;return PL$1;
});
})();
